@@ -38,7 +38,7 @@
 #include <gtk/gtkscrolledwindow.h>
 
 #include <gsf/gsf-impl-utils.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <stdio.h>
 
 /**************************************************************************/
