@@ -7,7 +7,7 @@
 
 #include <goffice/goffice-config.h>
 #include "go-math.h"
-#include <glib/gmessages.h>
+#include <glib.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <locale.h>
@@ -42,13 +42,15 @@ double go_ninf;
 void
 go_math_init (void)
 {
-	const char *bug_url = "http://bugzilla.gnome.org/enter_bug.cgi?product=gnumeric";
+	const char *bug_url = "http://bugzilla.gnome.org/enter_bug.cgi?product=libgoffice";
 	char *old_locale;
 	double d;
 #ifdef SIGFPE
 	void (*signal_handler)(int) = (void (*)(int))signal (SIGFPE, SIG_IGN);
 #endif
 
+	old_locale = g_strdup (setlocale (LC_ALL, NULL));
+
 	go_pinf = HUGE_VAL;
 	if (go_pinf > 0 && !go_finite (go_pinf))
 		goto have_pinf;
@@ -60,7 +62,7 @@ go_math_init (void)
 #endif
 
 	/* Try sscanf with fixed strings.  */
-	old_locale = setlocale (LC_ALL, "C");
+	setlocale (LC_ALL, "C");
 	if (sscanf ("Inf", "%lf", &d) != 1 &&
 	    sscanf ("+Inf", "%lf", &d) != 1)
 		d = 0;
@@ -97,7 +99,7 @@ go_math_init (void)
 		goto have_nan;
 
 	/* Try sscanf with fixed strings.  */
-	old_locale = setlocale (LC_ALL, "C");
+	setlocale (LC_ALL, "C");
 	if (sscanf ("NaN", "%lf", &d) != 1 &&
 	    sscanf ("NAN", "%lf", &d) != 1 &&
 	    sscanf ("+NaN", "%lf", &d) != 1 &&
@@ -131,6 +133,7 @@ go_math_init (void)
 	}
 #endif
 
+	g_free (old_locale);
 #ifdef SIGFPE
 	signal (SIGFPE, signal_handler);
 #endif
@@ -199,6 +202,13 @@ go_fake_trunc (double x)
 		: -floor (go_add_epsilon (-x));
 }
 
+double
+go_rint (double x)
+{
+	double y = floor (fabs (x) + 0.5);
+	return (x < 0) ? -y : y;
+}
+
 int
 go_finite (double x)
 {
@@ -530,13 +540,13 @@ modfl (long double x, long double *iptr)
 /* ------------------------------------------------------------------------- */
 
 void
-gnm_continued_fraction (double val, int max_denom, int *res_num, int *res_denom)
+go_continued_fraction (double val, int max_denom, int *res_num, int *res_denom)
 {
 	int n1, n2, d1, d2;
 	double x, y;
 
 	if (val < 0) {
-		gnm_continued_fraction (-val, max_denom, res_num, res_denom);
+		go_continued_fraction (-val, max_denom, res_num, res_denom);
 		*res_num = -*res_num;
 		return;
 	}
